#!/usr/bin/python

# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2021. All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

import sys
import requests
import logging
import json
import getpass

from requests.packages.urllib3.exceptions import InsecureRequestWarning

requests.packages.urllib3.disable_warnings(InsecureRequestWarning)

# intialize logger
logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
logger.propagate = False
loggerStdoutHandler = logging.StreamHandler(sys.stdout)
loggerStdoutHandler.setFormatter(logging.Formatter('%(levelname)s: %(asctime)s %(message)s'))
loggerStdoutHandler.setLevel(logging.DEBUG)
logger.addHandler(loggerStdoutHandler)

phase = 'GLOBALS'

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print('Usage: uninstallNBA1.py ipAddress')
        exit(2)

    ipAddress = sys.argv[1]

    username = raw_input("Username for " + ipAddress + " [admin]: ")
    if username == '':
        username = 'admin'

    pw = getpass.getpass("Password for " + ipAddress + ": ")

    base_url = "https://" + ipAddress + "/api/application/network_threat_analytics/hierarchical_clustering_algorithms"
    url = base_url + "?fields=id"

    requestHeaders = {"Content-Type": "application/json","Version": "15.0","Accept": "application/json","Allow-Hidden": "true"}

    algorithm_list = []
    try:
        get_algorithm_response = requests.get(url, headers = requestHeaders, auth = (username, pw), verify = False)
        if get_algorithm_response.status_code != 200:
                raise Exception('Failed to retrieve existing hierarchical clustering algorithms. Error code: {}'.format(get_algorithm_response.status_code))
        algorithm_list = get_algorithm_response.json()
    except:
        logger.error("Failed to retrieve existing hierarchical clustering algorithms.")
        raise
        exit(1)

    if len(algorithm_list) == 0:
        logger.debug("No hierarchical clustering algorithms to uninstall.")

    requestHeaders = {"Allow-Hidden": "true"}
    for installed_algorithm in algorithm_list:
        try:
            logger.debug('Uninstalling algorithm {}'.format(installed_algorithm['id']))
            url = "{}/{}".format(base_url, installed_algorithm['id'])
            logger.debug(url)
            delete_algorithm_response = requests.delete(url, headers = requestHeaders, auth = (username, pw))
            if delete_algorithm_response.status_code != 204:
                raise Exception('Failed to delete an existing hierarchical clustering algorithm. Error code: {}'.format(delete_algorithm_response.status_code))
            logger.debug(delete_algorithm_response)
        except:
            logger.error("Error uninstalling algorithm {}".format(installed_algorithm['id']))
            raise
            exit(1)

    logger.info("Uninstall complete")

